<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://kerosin.digital/
 * @since      1.0.0
 *
 * @package    Rss_Chimp
 * @subpackage Rss_Chimp/admin
 */
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Rss_Chimp
 * @subpackage Rss_Chimp/admin
 * @author     kerosin.digital <hello@kerosin.digital>
 */
class Rss_Chimp_Admin
{
    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private  $plugin_name ;
    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private  $version ;
    /**
     * The options name to be used in this plugin
     *
     * @since  	1.0.0
     * @access 	private
     * @var  	string 		$option_name 	Option name of this plugin
     */
    private  $option_name = 'rss_chimp' ;
    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version )
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }
    
    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {
        wp_enqueue_style(
            $this->plugin_name,
            plugin_dir_url( __FILE__ ) . 'css/rss-chimp-admin.css',
            array(),
            $this->version,
            'all'
        );
    }
    
    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {
        wp_enqueue_script(
            $this->plugin_name,
            plugin_dir_url( __FILE__ ) . 'js/rss-chimp-admin.js',
            array( 'jquery' ),
            $this->version,
            false
        );
    }
    
    /**
     * Reccomended plugins
     *
     * @since    1.0.0
     */
    function rss_chimp_register_required_plugins()
    {
        $plugins = array( array(
            'name' => 'Regenerate Thumbnails',
            'slug' => 'regenerate-thumbnails',
        ) );
        $config = array(
            'id'           => 'rss-chimp-recommended-plugins',
            'default_path' => '',
            'menu'         => 'rss-chimp-recommended-plugins',
            'parent_slug'  => 'plugins.php',
            'capability'   => 'manage_options',
            'has_notices'  => false,
            'dismissable'  => true,
            'dismiss_msg'  => '',
            'is_automatic' => false,
        );
        tgmpa( $plugins, $config );
    }
    
    /**
     * Create plugin pages.
     *
     * @since    1.0.0
     */
    public function rss_chimp_menu_pages()
    {
        
        if ( is_plugin_active( 'adminion/adminion.php' ) ) {
            $this->plugin_screen_hook_suffix = add_submenu_page(
                'adminion',
                __( 'RSS Chimp', 'rss-chimp' ),
                __( 'RSS Chimp', 'rss-chimp' ),
                'manage_options',
                $this->plugin_name,
                array( $this, 'rss_chimp_admin_display' )
            );
        } else {
            $this->plugin_screen_hook_suffix = add_menu_page(
                __( 'RSS Chimp', 'rss-chimp' ),
                __( 'RSS Chimp', 'rss-chimp' ),
                'manage_options',
                'rss-chimp',
                array( $this, 'rss_chimp_admin_display' ),
                'dashicons-rss'
            );
        }
    
    }
    
    /**
     * Render plugin pages.
     *
     * @since  1.0.0
     */
    public function rss_chimp_admin_display()
    {
        include_once 'partials/rss-chimp-admin-display.php';
    }
    
    /**
     * Register all related settings of this plugin
     *
     * @since  1.0.0
     */
    public function rss_chimp_settings_init()
    {
        // Default feed
        add_settings_section(
            $this->option_name . '_defaultfeed',
            __( 'Default feed', 'rss-chimp' ),
            array( $this, $this->option_name . '_defaultfeed_cb' ),
            $this->plugin_name . '_defaultfeed'
        );
        add_settings_field(
            $this->option_name . '_defaultfeed_disable',
            __( 'Disable default feeds', 'rss-chimp' ),
            array( $this, $this->option_name . '_defaultfeed_disable_cb' ),
            $this->plugin_name . '_defaultfeed',
            $this->option_name . '_defaultfeed',
            array(
            'label_for' => $this->option_name . '_defaultfeed_disable',
        )
        );
        register_setting( $this->plugin_name . '_tab_general', $this->option_name . '_defaultfeed_disable' );
        add_settings_field(
            $this->option_name . '_defaultfeed_imagesize',
            __( 'Image size for the default WordPress feed', 'rss-chimp' ),
            array( $this, $this->option_name . '_defaultfeed_imagesize_cb' ),
            $this->plugin_name . '_defaultfeed',
            $this->option_name . '_defaultfeed',
            array(
            'label_for' => $this->option_name . '_defaultfeed_imagesize',
        )
        );
        register_setting( $this->plugin_name . '_tab_general', $this->option_name . '_defaultfeed_imagesize' );
        //Other settings
        add_settings_section(
            $this->option_name . '_othersettings',
            __( 'Other options', 'rss-chimp' ),
            array( $this, $this->option_name . '_othersettings_cb' ),
            $this->plugin_name . '_othersettings'
        );
        add_settings_field(
            $this->option_name . '_reset',
            __( 'Reset all options on deactivation', 'rss-chimp' ),
            array( $this, $this->option_name . '_reset_cb' ),
            $this->plugin_name . '_othersettings',
            $this->option_name . '_othersettings',
            array(
            'label_for' => $this->option_name . '_reset',
        )
        );
        register_setting( $this->plugin_name . '_tab_general', $this->option_name . '_reset' );
    }
    
    /**
     * Render the text for the default feed settings
     *
     * @since  1.0.0
     */
    public function rss_chimp_defaultfeed_cb()
    {
        $optinlink = admin_url( 'plugins.php' );
        $upgradelink = rss_chimp_fs()->get_upgrade_url();
        echo  '<p>' ;
        echo  __( 'Here you can customize the default WordPress feed and set the size of the attached image.', 'rss-chimp' ) ;
        
        if ( rss_chimp_fs()->is_plan( 'free' ) ) {
            echo  '<br>' ;
            echo  sprintf( __( '<a href="%1$s">Upgrade to pro</a> for all image sizes and many more features.', 'rss-chimp' ), $upgradelink ) ;
        } else {
            echo  '<br>' ;
            echo  sprintf( __( '<a href="%1$s">Opt in your plugin</a> and unlock one more image size for free. <a href="%2$s">Upgrade to pro</a> for all image sizes and many more features.', 'rss-chimp' ), $optinlink, $upgradelink ) ;
        }
        
        echo  '</p>' ;
    }
    
    /**
     * Render the text for the other settings
     *
     * @since  1.0.0
     */
    public function rss_chimp_othersettings_cb()
    {
        //echo '<p>';
        //echo  __( 'Adapt the feeds created by WordPress to your needs.' );
        //echo '</p>';
    }
    
    /**
     * Render the checkbox for disabeling the comment feeds
     *
     * @since  1.0.0
     */
    public function rss_chimp_defaultfeed_disable_cb()
    {
        echo  '<input type="checkbox" name="' . $this->option_name . '_defaultfeed_disable' . '" value="1" "' . checked( 1, get_option( 'rss_chimp_defaultfeed_disable' ), false ) . '" />' ;
    }
    
    /**
     * Render the image size settings for the default feed
     *
     * @since  1.0.0
     */
    public function rss_chimp_defaultfeed_imagesize_cb()
    {
        
        if ( rss_chimp_fs()->is_plan( 'pro', true ) ) {
            $position = get_option( $this->option_name . '_defaultfeed_imagesize' );
            $_wp_additional_image_sizes[$name] = array( $width, $height, $crop );
            $image_sizes = get_intermediate_image_sizes();
            echo  '<select name="' . $this->option_name . '_defaultfeed_imagesize' . '" class="input">' ;
            foreach ( $image_sizes as $size ) {
                echo  '<option value="' . $size . '"' . selected( get_option( 'rss_chimp_defaultfeed_imagesize' ), $size ) . '>' . $size . '</option>' ;
            }
            echo  '</select>' ;
        } else {
            
            if ( rss_chimp_fs()->is_plan( 'free' ) ) {
                $position = get_option( $this->option_name . '_defaultfeed_imagesize' );
                $_wp_additional_image_sizes[$name] = array( $width, $height, $crop );
                $image_sizes = array(
                    "thumbnail"       => "thumbnail",
                    "rss-chimp-small" => "rss-chimp-small",
                );
                echo  '<select name="' . $this->option_name . '_defaultfeed_imagesize' . '" class="input">' ;
                foreach ( $image_sizes as $size ) {
                    echo  '<option value="' . $size . '"' . selected( get_option( 'rss_chimp_defaultfeed_imagesize' ), $size ) . '>' . $size . '</option>' ;
                }
                echo  '</select>' ;
            } else {
                $position = get_option( $this->option_name . '_defaultfeed_imagesize' );
                $_wp_additional_image_sizes[$name] = array( $width, $height, $crop );
                $image_sizes = array(
                    "thumbnail" => "thumbnail",
                );
                echo  '<select disabled class="input">' ;
                foreach ( $image_sizes as $size ) {
                    echo  '<option>' . $size . '</option>' ;
                }
                echo  '</select>' ;
            }
        
        }
    
    }
    
    /**
     * Render the checkbox for removing version number from feeds
     *
     * @since  1.1.0
     */
    public function rss_chimp_reset_cb()
    {
        echo  '<input type="checkbox" name="' . $this->option_name . '_reset' . '" value="1" "' . checked( 1, get_option( 'rss_chimp_reset' ), false ) . '" />' ;
    }
    
    /**
     * Add additional image sizes
     *
     * @since    1.0.0
     */
    function rss_chimp_imagesizes()
    {
        if ( rss_chimp_fs()->is_plan( 'free' ) ) {
            add_image_size(
                'rss-chimp-small',
                150,
                84,
                TRUE
            );
        }
    }
    
    /**
     * Extend the RSS namespace with the media specification
     *
     * @since    1.0.0
     */
    function rss_chimp_add_namespace()
    {
        echo  'xmlns:media="http://search.yahoo.com/mrss/"' . "\n" ;
    }
    
    /**
     * Add the featured image
     *
     * @since    1.0.0
     */
    function rss_chimp_add_featuredimage()
    {
        global  $post ;
        $output = '';
        if ( get_post_type() !== 'post' ) {
            return;
        }
        
        if ( has_post_thumbnail( $post->ID ) ) {
            
            if ( rss_chimp_fs()->is_plan( 'free' ) or rss_chimp_fs()->is_plan( 'pro', true ) ) {
                $imagesize = get_option( $this->option_name . '_defaultfeed_imagesize' );
            } else {
                $imagesize = 'thumbnail';
            }
            
            $output = '<media:content url="' . get_the_post_thumbnail_url( $post->ID, $imagesize ) . '" medium="image" type="image/jpg" />';
        }
        
        echo  $output ;
    }
    
    /**
     * Add generator tag for RSS Chimp
     *
     * @since  1.0.0
     */
    function rss_chimp_add_generatortag()
    {
        echo  '<generator>https://kerosin.digital/rss-chimp</generator>' ;
    }
    
    /**
     * Remove the WordPress generator tag from all feeds
     *
     * @since  1.0.0
     */
    function rss_chimp_remove_generatortag()
    {
        remove_action( 'rss2_head', 'the_generator' );
        remove_action( 'rss_head', 'the_generator' );
        remove_action( 'rdf_header', 'the_generator' );
        remove_action( 'atom_head', 'the_generator' );
        remove_action( 'commentsrss2_head', 'the_generator' );
        remove_action( 'opml_head', 'the_generator' );
        remove_action( 'app_head', 'the_generator' );
        remove_action( 'comments_atom_head', 'the_generator' );
    }
    
    /**
     * Disable certain feeds
     *
     * @since  1.0.0
     */
    function rss_chimp_redirect_disabled_feed()
    {
        wp_redirect( home_url() );
        die;
    }

}